﻿using Microsoft.EntityFrameworkCore;
using QuickMasterRazor.Models;
using Microsoft.Extensions.DependencyInjection;
using QuickMasterRazor.Filters;

var builder = WebApplication.CreateBuilder(args);

// Add services to the container.

//builder.Services.AddRazorPages()
//    .AddMvcOptions(options =>
//    {
//        options.Filters.Add(new MyFilter(builder.Configuration));
//    });

builder.Services.AddRazorPages(options =>
{
    options.Conventions.AddFolderApplicationModelConvention(
      "/Books",
      model => model.Filters.Add(new MyFilter(builder.Configuration))
    );
});

builder.Services.AddDbContext<MyContext>(options =>
  options.UseSqlServer(builder.Configuration.GetConnectionString("MyContext")));

//builder.Services.AddWebOptimizer();

builder.Services.AddWebOptimizer(pipeline =>
{
	pipeline.MinifyCssFiles("css/**/*.css");
});

//builder.Services.AddWebOptimizer(pipeline =>
//    //pipeline.AddJavaScriptBundle("/js/app.js", "js/site.js", "js/site2.js"));
//    pipeline.AddJavaScriptBundle("/js/app.js", "js/**/*.js"));

var app = builder.Build();

// Configure the HTTP request pipeline.
if (!app.Environment.IsDevelopment())
{
    app.UseExceptionHandler("/Error");
    // The default HSTS value is 30 days. You may want to change this for production scenarios, see https://aka.ms/aspnetcore-hsts.
    app.UseHsts();
}

app.UseHttpsRedirection();
app.UseWebOptimizer();
app.UseStaticFiles();

app.UseRouting();

app.UseAuthorization();

app.MapRazorPages();

app.Run();
